@@ -32,17 +32,17 @@ class Accountant:
         book_balance = []
         for currency, amount in blocked_balance_book.items():
             if currency in main_balance_book:
-                main_balance = float(main_balance_book[currency])
+                main_balance = main_balance_book[currency]
             else:
-                main_balance = float(0)
+                main_balance = "0"
             if currency in blocked_balance_deposit_book:
-                blocked_balance_deposit = float(blocked_balance_deposit_book[currency])
+                blocked_balance_deposit = blocked_balance_deposit_book[currency]
             else:
-                blocked_balance_deposit = float(0)
+                blocked_balance_deposit = "0"
             if currency in blocked_balance_withdraw_book:
-                blocked_balance_withdraw = float(blocked_balance_withdraw_book[currency])
+                blocked_balance_withdraw = blocked_balance_withdraw_book[currency]
             else:
-                blocked_balance_withdraw = float(0)
+                blocked_balance_withdraw = "0"
             balance = {
                 'currency': currency,
                 'blocked_balance_deposit': blocked_balance_deposit,
@@ -63,9 +63,9 @@ class Accountant:
         main_balance = self.ledger.get_book_balances(book_id=self.bank_account['ledger_books']['main_balance']['id'],
                                                      asset_id=currency, metadata_filter={**metadata_filter})
         return {'currency': currency,
-                'blocked_balance_deposit': float(blocked_deposit_balance.get(currency, 0)),
-                'blocked_balance_withdraw': float(blocked_withdraw_balance.get(currency, 0)),
-                'main_balance': float(main_balance.get(currency, 0))}
+                'blocked_balance_deposit': blocked_deposit_balance.get(currency, "0"),
+                'blocked_balance_withdraw': blocked_withdraw_balance.get(currency, "0"),
+                'main_balance': main_balance.get(currency, "0")}
 
     def withdraw_block_amount(self, value: str, currency: str, memo: str, metadata: dict = {}):
         log.info("---------Block_Amount_Withdraw----------")
@@ -159,4 +159,4 @@ class Accountant:
                                 'id': block_book_id['id']}
         }
         log.info(new_books)
-        return new_books
\ No newline at end of file
+        return new_books
