@@ -31,7 +31,7 @@ class LedgerClient:
 
     def _execute(self, method: str, *args, read_only_method: bool = False):
         start_time = int(time.time()*1000)
-        if read_only_method is True and self.read_only_rpc_client:
+        if read_only_method is True and getattr(self, "read_only_rpc_client", None) is not None:
             rpc_response = self.read_only_rpc_client.request(method, *args)
         else:
             rpc_response = self.rpc_client.request(method, *args)
